pub enum Token<'s> {
Word(&'s str),
Special {
raw: &'s str,
normalized: Cow<'s, str>,
},
}Variants
Word(&'s str)
Any word, for which fuzzy matching can be applied.
Special
A special token, like an email address, which should not be fuzzy matched.